@@ -1,12 +1,10 @@
 """Image captioning models for captionflow."""
 
-from .base import BaseModel
 from .florence2 import Florence2
 from .wd14 import WD14
 from .vlm import VLM
 
 __all__ = [
-    "BaseModel",
     "Florence2",
     "WD14",
     "VLM",
