@@ -1,4 +1,4 @@
-"""Utility modules for captionflow."""
+"""Utility modules for capflow."""
 
 from .device import get_optimal_device, get_torch_dtype
 from .exif import (
@@ -7,6 +7,7 @@ from .exif import (
     get_capture_settings,
     get_datetime,
 )
+from .image import resize_with_padding, resize_keep_aspect
 
 __all__ = [
     "get_optimal_device",
@@ -15,4 +16,6 @@ __all__ = [
     "get_camera_info",
     "get_capture_settings",
     "get_datetime",
+    "resize_with_padding",
+    "resize_keep_aspect",
 ]
