@@ -1,17 +1,18 @@
 """Device selection utilities for cross-platform compatibility."""
 
-import torch
 import logging
 
+import torch
+
 logger = logging.getLogger(__name__)
 
 
-def get_optimal_device() -> str:
+def get_optimal_device() -> torch.device:
     """
     Automatically select the optimal device based on available hardware.
 
     Returns:
-        str: Device name ("cuda", "mps", or "cpu")
+        torch.device: Optimal device ("cuda", "mps", or "cpu")
     """
     if torch.cuda.is_available():
         device = "cuda"
@@ -23,23 +24,23 @@ def get_optimal_device() -> str:
         device = "cpu"
         logger.info("Using CPU device (inference will be slower)")
 
-    return device
+    return torch.device(device)
 
 
-def get_torch_dtype(device: str) -> torch.dtype:
+def get_torch_dtype(device: torch.device) -> torch.dtype:
     """
     Get the appropriate torch dtype for the given device.
 
     Args:
-        device: Device name ("cuda", "mps", or "cpu")
+        device: Target device
 
     Returns:
         torch.dtype: Recommended dtype for the device
     """
-    if device == "cuda":
+    if "cuda" in device.type:
         # Use float16 for CUDA to save VRAM
         return torch.float16
-    elif device == "mps":
+    elif "mps" in device.type:
         # MPS has better support for float32
         return torch.float32
     else:
